@@ -493,6 +493,17 @@ func (a *Auth) getProxyAddress(r *http.Request, state string, namespace string)
 }
 
 func getRootNamespaceID(r *http.Request) string {
+	id, err := domain.FromRequest(r).GetRootNamespaceID()
+	if err != nil {
+		logging.LogRequest(r).WithError(err).Error("Failed to get RootNamespaceID")
+		return ""
+	}
+
+	if id > 0 {
+		return strconv.Itoa(id)
+	}
+
+	// Keep lookupPath.RootNamespaceID to support old rails response, remove in 18.6.
 	lookupPath, err := domain.FromRequest(r).GetLookupPath(r)
 	if err != nil {
 		logging.LogRequest(r).WithError(err).Error("RootNamespaceID: failed to get lookupPath")
@@ -502,6 +513,7 @@ func getRootNamespaceID(r *http.Request) string {
 	if lookupPath.RootNamespaceID > 0 {
 		return strconv.Itoa(lookupPath.RootNamespaceID)
 	}
+
 	return ""
 }
 
